% Smith Predictor for Magnetic Suspension
clear all;
% Vehicle Model Parameters
K_IP = 7.7;
T_IP = 0.3;
K_VD = 0.17;
T_VD = 19.5;
K_d = 11.5;

% =============================================
% Smith Predictor for Magnetic Suspension
% =============================================
% Bearing Model Parameters
Km = 1E-4;
d = 0.04;
m = 0.1;
g = 10;
i0 = sqrt(m*g/Km)*d/2;
Ki = 2*Km*i0/(d/2)^2;
Kx = 2*Km*i0^2/(d/2)^3;

% Inner Loop
tau = sqrt(m/Kx);
T2 = 1/3;
K_R = (tau^2/3 + 1)*Kx/Ki;
T1 = (3 + 1/tau^2)/(1 + 3/tau^2);

% ====================================
% Feedback Loop with time delay
% reference tracking
options = simset('Solver','ode23s');
ref = 1;
d_load = 0;
smith_on = 0;
sim('ECE441_Ex6_solution_13',[0,5],options);
figure(3);
plot(time,y);
legend('reference step $x = d/4$')
grid
xlabel('time [sec]')
ylabel('potition [m/s]')
% Discturbancestep
ref = 0;
d_load = 0.05;
sim('ECE441_Ex6_solution_13',[0,5],options);
figure(4);
plot(time,y);
legend('disturbance step $F_\mathrm{L} = 0.5 N$','Interpreter','latex')
grid
xlabel('time [sec]')
ylabel('position [m/s]')

% ====================================
% Smith Predictor
% reference tracking
options = simset('Solver','ode23s');
ref = 1;
d_load = 0;
smith_on = 1;
sim('ECE441_Ex6_solution_13',[0,5],options);
figure(5);
plot(time,y);
legend('reference step $x = d/4$')
grid
xlabel('time [sec]')
ylabel('potition [m/s]')
% Discturbancestep
ref = 0;
d_load = 0.05;
sim('ECE441_Ex6_solution_13',[0,5],options);
figure(6);
plot(time,y);
legend('disturbance step $F_\mathrm{L} = 0.5 N$','Interpreter','latex')
grid
xlabel('time [sec]')
ylabel('position [m/s]')